mir.cp README
=============

.. image:: https://circleci.com/gh/darkfeline/mir.cp.svg?style=shield
   :target: https://circleci.com/gh/darkfeline/mir.cp
   :alt: CircleCI
.. image:: https://codecov.io/gh/darkfeline/mir.cp/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/darkfeline/mir.cp
   :alt: Codecov
.. image:: https://badge.fury.io/py/mir.cp.svg
   :target: https://badge.fury.io/py/mir.cp
   :alt: PyPI Release
.. image:: https://readthedocs.org/projects/mir-cp/badge/?version=latest
   :target: http://mir-cp.readthedocs.io/en/latest/
   :alt: Latest Documentation

Cached property implementations.

Look at the code and tests for SemVer public API.
